# Dify 安装与部署指南（v0.15.3）

## 前提条件

- 已安装 Git
- 有可用的服务器或本地环境
- 服务器可访问互联网

---

## 1. 拉取源码

1. 克隆指定版本源码：
    ```bash
    git clone https://github.com/langgenius/dify.git --branch 0.15.3
    ```
2. 进入项目根目录，新建 `dify` 文件夹并移动源码：
    ```bash
    mkdir dify
    mv dify-0.15.3/* dify/
    ```
3. （可选）若您已下载压缩包，解压到 `dify/`：
    ```bash
    unzip dify.zip -d dify/
    ```

---

## 2. 安装并启动 Docker

1. 使用阿里云镜像一键安装：
    ```bash
    curl -fsSL https://get.docker.com | bash -s docker --mirror Aliyun
    ```
2. 启动并设置开机自启：
    ```bash
    sudo systemctl start docker
    sudo systemctl enable docker
    ```
3. 测试 Docker：
    ```bash
    sudo docker run hello-world
    ```

---

## 3. 配置镜像加速

1. 编辑 `/etc/docker/daemon.json`：
    ```bash
    sudo vim /etc/docker/daemon.json
    ```
2. 添加或替换为：
    ```json
    {
      "registry-mirrors": [
        "https://docker.xuanyuan.me",
        "https://dytt.online"
      ]
    }
    ```
3. 重载并重启 Docker：
    ```bash
    sudo systemctl daemon-reload
    sudo systemctl restart docker
    ```
4. 验证配置：
    ```bash
    docker info
    ```

---

## 4. 启动 Dify 服务

1. 进入 Dify 的 Docker 配置目录：
    ```bash
    cd dify/docker
    ```
2. 复制环境变量示例并编辑 `.env`：
    ```bash
    cp .env.example .env
    vim .env   # 根据需求修改端口、数据库等配置
    ```
3. 启动容器：
    ```bash
    docker compose up -d
    ```
4. 检查容器状态，确认全部正常运行：
    ```bash
    docker compose ps
    ```

---

## 5. 访问平台

在浏览器中打开：
http://<服务器IP或域名>/apps

如页面无法访问，请检查：
- 防火墙/安全组规则
- `.env` 中的端口配置
- Docker 容器日志：`docker compose logs -f`

---

## 常见问题 & 拓展

- **端口冲突**：修改 `.env` 中的端口映射后重启服务。
- **Nginx/SSL**：可在外层使用 Nginx 做反向代理及证书托管。
- **内网穿透**：推荐使用 Cloudflare Tunnel、frp 等工具。

---